---
name: 🚅 Good first issue
about: Create a good first issue to help new contributors
labels: good first issue
---

### 🚅Search before asking

<!-- Please search for relevant issues before creating a new issue. -->

<!-- 描述问题在已经提交的ISSUE中是否已存在 -->

I have searched for issues similar to this one.

### 🚅Description

<!-- Describe the issue clearly and concisely. Include screenshots if possible -->

<!-- 描述问题清晰简洁，如果可能的话请附上截图 -->

Example：ClickHouse support some IP address process function for SQL. These are very useful for some network service cases.
Hope to add these function ASAP.Thanks.

### 🏕Solution(*optional*)

<!-- Describe how you think this issue should be solved -->

<!-- 描述你认为这个问题应该如何解决 -->

Example：Add IP address process function for SQL like ClickHouse

### 🍰Detail(*optional*)

<!-- Describe any other details you think are relevant, parameters, etc. -->

<!-- 描述你认为其他相关的细节,比如出参入参 -->

### 🍰Example(*optional*)
